{
    "$graph": [
        {
            "label": "Merge rRNA Alignments",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "align_merge",
            "arguments": [
                "-filter",
                "align_length >= 60",
                "-ifmt",
                "seq-align-set",
                "-max-discontinuity",
                "20",
                "-collated",
                "-compart",
                "-fill-gaps"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#align_merge.cwl/alignments"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#align_merge.cwl/asn_cache"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-blastdb",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#align_merge.cwl/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#align_merge.cwl/blastdb_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#align_merge.cwl/output"
                }
            ],
            "id": "#align_merge.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#align_merge.cwl/aligns"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#align_merge.cwl/asncache"
                }
            ]
        },
        {
            "label": "Post-process CMsearch annotations",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        }
                    ]
                }
            ],
            "baseCommand": "annot_merge",
            "arguments": [
                "-unique"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#annot_merge.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#annot_merge.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "annots.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#annot_merge.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#annot_merge.cwl/annots"
                }
            ],
            "id": "#annot_merge.cwl"
        },
        {
            "label": "BLAST against rRNA db, execution",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "blastn_wnode",
            "arguments": [
                "-evalue",
                "0.01",
                "-max_target_seqs",
                "250",
                "-soft_masking",
                "true",
                "-task",
                "blastn",
                "-word_size",
                "12",
                "-swap-rows"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#blastn_wnode.cwl/asn_cache"
                },
                {
                    "type": "Directory",
                    "id": "#blastn_wnode.cwl/blastdb_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-jobs"
                    },
                    "id": "#blastn_wnode.cwl/input_jobs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#blastn_wnode.cwl/output_dir"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#blastn_wnode.cwl/asncache"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir)"
                    },
                    "id": "#blastn_wnode.cwl/outdir"
                }
            ],
            "id": "#blastn_wnode.cwl"
        },
        {
            "label": "Run genomic CMsearch (5S rRNA), execution",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        }
                    ]
                }
            ],
            "baseCommand": "cmsearch_wnode",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#cmsearch_wnode.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "prefix": "-cmsearch-cpu"
                    },
                    "id": "#cmsearch_wnode.cwl/cmsearch_cpu"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "/gpipe/bin",
                    "inputBinding": {
                        "prefix": "-cmsearch-path"
                    },
                    "id": "#cmsearch_wnode.cwl/cmsearch_path"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-jobs"
                    },
                    "id": "#cmsearch_wnode.cwl/input_jobs"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-model-path"
                    },
                    "id": "#cmsearch_wnode.cwl/model_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#cmsearch_wnode.cwl/output_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-rfam-amendments"
                    },
                    "id": "#cmsearch_wnode.cwl/rfam_amendments"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-rfam-stockholm"
                    },
                    "id": "#cmsearch_wnode.cwl/rfam_stockholm"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#cmsearch_wnode.cwl/asncache"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir)"
                    },
                    "id": "#cmsearch_wnode.cwl/outdir"
                }
            ],
            "id": "#cmsearch_wnode.cwl"
        },
        {
            "label": "BLAST against rRNA db, gather",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "gpx_make_outputs",
            "arguments": [
                "-unzip",
                "*",
                "-num-partitions",
                "1"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-input-path"
                    },
                    "id": "#gpx_make_outputs.cwl/input_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "blast.#.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_make_outputs.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "blast.*.asn"
                    },
                    "id": "#gpx_make_outputs.cwl/blast_align"
                }
            ],
            "id": "#gpx_make_outputs.cwl"
        },
        {
            "label": "Run genomic CMsearch (5S rRNA), gather",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "gpx_qdump",
            "arguments": [
                "-unzip",
                "*"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-input-path"
                    },
                    "id": "#gpx_qdump.cwl/input_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cmsearch.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qdump.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#gpx_qdump.cwl/annots"
                }
            ],
            "id": "#gpx_qdump.cwl"
        },
        {
            "label": "BLAST against rRNA db, scatter",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "gpx_qsubmit",
            "arguments": [
                "-affinity",
                "subject",
                "-max-batch-length",
                "50000"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-db",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/blastdb"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "id": "#gpx_qsubmit_blastn.cwl/blastdb_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "jobs.xml",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-ids"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/asncache"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/jobs"
                }
            ],
            "id": "#gpx_qsubmit_blastn.cwl"
        },
        {
            "label": "BLAST against rRNA db, scatter",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        }
                    ]
                }
            ],
            "baseCommand": "gpx_qsubmit",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#gpx_qsubmit_gcmsearch.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "jobs.xml",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qsubmit_gcmsearch.cwl/output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-ids"
                    },
                    "id": "#gpx_qsubmit_gcmsearch.cwl/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#gpx_qsubmit_gcmsearch.cwl/asncache"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#gpx_qsubmit_gcmsearch.cwl/jobs"
                }
            ],
            "id": "#gpx_qsubmit_gcmsearch.cwl"
        },
        {
            "label": "Generate rRNA Annotation",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "ncbi/bacterial_noncoding:pgap4.4",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": true
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "ribosomal_align2annot",
            "arguments": [
                "-filter-accept",
                "pct_identity_gap >= 70",
                "-gap-tolerance",
                "1000",
                "-submission-mode-genbank"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#ribosomal_align2annot.cwl/alignments"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "annotations.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#ribosomal_align2annot.cwl/annotation"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#ribosomal_align2annot.cwl/asn_cache"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-blastdb",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#ribosomal_align2annot.cwl/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#ribosomal_align2annot.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-product-name"
                    },
                    "id": "#ribosomal_align2annot.cwl/product_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.annotation)"
                    },
                    "id": "#ribosomal_align2annot.cwl/annotations"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#ribosomal_align2annot.cwl/asncache"
                }
            ],
            "id": "#ribosomal_align2annot.cwl"
        },
        {
            "label": "Non-Coding Bacterial Genes",
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#main/16s_blastdb_dir"
                },
                {
                    "type": "Directory",
                    "id": "#main/23s_blastdb_dir"
                },
                {
                    "type": "Directory",
                    "id": "#main/asn_cache"
                },
                {
                    "type": "File",
                    "id": "#main/model_path"
                },
                {
                    "type": "File",
                    "id": "#main/rfam_amendments"
                },
                {
                    "type": "File",
                    "id": "#main/rfam_stockholm"
                },
                {
                    "type": "File",
                    "id": "#main/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/generate_16s/annotations",
                    "id": "#main/annotations_16s"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_23s/annotations",
                    "id": "#main/annotations_23s"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_5s/annots",
                    "id": "#main/annotations_5s"
                }
            ],
            "steps": [
                {
                    "run": "#wf_blastn.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/generate_16s/asn_cache"
                        },
                        {
                            "default": "blastdb",
                            "id": "#main/generate_16s/blastdb"
                        },
                        {
                            "source": "#main/16s_blastdb_dir",
                            "id": "#main/generate_16s/blastdb_dir"
                        },
                        {
                            "default": "annotations_16s.asn",
                            "id": "#main/generate_16s/outname"
                        },
                        {
                            "default": "16S ribosomal RNA",
                            "id": "#main/generate_16s/product_name"
                        },
                        {
                            "source": "#main/seqids",
                            "id": "#main/generate_16s/seqids"
                        }
                    ],
                    "out": [
                        "#main/generate_16s/asncache",
                        "#main/generate_16s/annotations"
                    ],
                    "id": "#main/generate_16s"
                },
                {
                    "run": "#wf_blastn.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/generate_23s/asn_cache"
                        },
                        {
                            "default": "Ribosom23S",
                            "id": "#main/generate_23s/blastdb"
                        },
                        {
                            "source": "#main/23s_blastdb_dir",
                            "id": "#main/generate_23s/blastdb_dir"
                        },
                        {
                            "default": "annotations_23s.asn",
                            "id": "#main/generate_23s/outname"
                        },
                        {
                            "default": "23S ribosomal RNA",
                            "id": "#main/generate_23s/product_name"
                        },
                        {
                            "source": "#main/seqids",
                            "id": "#main/generate_23s/seqids"
                        }
                    ],
                    "out": [
                        "#main/generate_23s/asncache",
                        "#main/generate_23s/annotations"
                    ],
                    "id": "#main/generate_23s"
                },
                {
                    "run": "#wf_gcmsearch.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/generate_5s/asn_cache"
                        },
                        {
                            "source": "#main/model_path",
                            "id": "#main/generate_5s/model_path"
                        },
                        {
                            "source": "#main/rfam_amendments",
                            "id": "#main/generate_5s/rfam_amendments"
                        },
                        {
                            "source": "#main/rfam_stockholm",
                            "id": "#main/generate_5s/rfam_stockholm"
                        },
                        {
                            "source": "#main/seqids",
                            "id": "#main/generate_5s/seqids"
                        }
                    ],
                    "out": [
                        "#main/generate_5s/annots"
                    ],
                    "id": "#main/generate_5s"
                }
            ],
            "id": "#main"
        },
        {
            "label": "BLAST against rRNA db",
            "class": "Workflow",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#wf_blastn.cwl/asn_cache"
                },
                {
                    "type": "string",
                    "id": "#wf_blastn.cwl/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#wf_blastn.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "id": "#wf_blastn.cwl/outname"
                },
                {
                    "type": "string",
                    "id": "#wf_blastn.cwl/product_name"
                },
                {
                    "type": "File",
                    "id": "#wf_blastn.cwl/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_blastn.cwl/ribosomal_align2annot/annotations",
                    "id": "#wf_blastn.cwl/annotations"
                },
                {
                    "type": "Directory",
                    "outputSource": "#wf_blastn.cwl/ribosomal_align2annot/asncache",
                    "id": "#wf_blastn.cwl/asncache"
                }
            ],
            "steps": [
                {
                    "run": "#align_merge.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/gpx_make_outputs/blast_align",
                            "id": "#wf_blastn.cwl/align_merge/alignments"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastn_wnode/asncache",
                            "id": "#wf_blastn.cwl/align_merge/asn_cache"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb",
                            "id": "#wf_blastn.cwl/align_merge/blastdb"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb_dir",
                            "id": "#wf_blastn.cwl/align_merge/blastdb_dir"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/align_merge/asncache",
                        "#wf_blastn.cwl/align_merge/aligns"
                    ],
                    "id": "#wf_blastn.cwl/align_merge"
                },
                {
                    "run": "#blastn_wnode.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/gpx_qsubmit/asncache",
                            "id": "#wf_blastn.cwl/blastn_wnode/asn_cache"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb_dir",
                            "id": "#wf_blastn.cwl/blastn_wnode/blastdb_dir"
                        },
                        {
                            "source": "#wf_blastn.cwl/gpx_qsubmit/jobs",
                            "id": "#wf_blastn.cwl/blastn_wnode/input_jobs"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/blastn_wnode/asncache",
                        "#wf_blastn.cwl/blastn_wnode/outdir"
                    ],
                    "id": "#wf_blastn.cwl/blastn_wnode"
                },
                {
                    "run": "#gpx_make_outputs.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/blastn_wnode/outdir",
                            "id": "#wf_blastn.cwl/gpx_make_outputs/input_path"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/gpx_make_outputs/blast_align"
                    ],
                    "id": "#wf_blastn.cwl/gpx_make_outputs"
                },
                {
                    "run": "#gpx_qsubmit_blastn.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/asn_cache",
                            "id": "#wf_blastn.cwl/gpx_qsubmit/asn_cache"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb",
                            "id": "#wf_blastn.cwl/gpx_qsubmit/blastdb"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb_dir",
                            "id": "#wf_blastn.cwl/gpx_qsubmit/blastdb_dir"
                        },
                        {
                            "source": "#wf_blastn.cwl/seqids",
                            "id": "#wf_blastn.cwl/gpx_qsubmit/seqids"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/gpx_qsubmit/asncache",
                        "#wf_blastn.cwl/gpx_qsubmit/jobs"
                    ],
                    "id": "#wf_blastn.cwl/gpx_qsubmit"
                },
                {
                    "run": "#ribosomal_align2annot.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/align_merge/aligns",
                            "id": "#wf_blastn.cwl/ribosomal_align2annot/alignments"
                        },
                        {
                            "source": "#wf_blastn.cwl/outname",
                            "id": "#wf_blastn.cwl/ribosomal_align2annot/annotation"
                        },
                        {
                            "source": "#wf_blastn.cwl/align_merge/asncache",
                            "id": "#wf_blastn.cwl/ribosomal_align2annot/asn_cache"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb",
                            "id": "#wf_blastn.cwl/ribosomal_align2annot/blastdb"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb_dir",
                            "id": "#wf_blastn.cwl/ribosomal_align2annot/blastdb_dir"
                        },
                        {
                            "source": "#wf_blastn.cwl/product_name",
                            "id": "#wf_blastn.cwl/ribosomal_align2annot/product_name"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/ribosomal_align2annot/asncache",
                        "#wf_blastn.cwl/ribosomal_align2annot/annotations"
                    ],
                    "id": "#wf_blastn.cwl/ribosomal_align2annot"
                }
            ],
            "id": "#wf_blastn.cwl"
        },
        {
            "label": "Run genomic CMsearch (5S rRNA)",
            "class": "Workflow",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#wf_gcmsearch.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "id": "#wf_gcmsearch.cwl/model_path"
                },
                {
                    "type": "File",
                    "id": "#wf_gcmsearch.cwl/rfam_amendments"
                },
                {
                    "type": "File",
                    "id": "#wf_gcmsearch.cwl/rfam_stockholm"
                },
                {
                    "type": "File",
                    "id": "#wf_gcmsearch.cwl/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_gcmsearch.cwl/annot_merge/annots",
                    "id": "#wf_gcmsearch.cwl/annots"
                }
            ],
            "steps": [
                {
                    "run": "#annot_merge.cwl",
                    "in": [
                        {
                            "source": "#wf_gcmsearch.cwl/cmsearch_wnode/asncache",
                            "id": "#wf_gcmsearch.cwl/annot_merge/asn_cache"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/gpx_qdump/annots",
                            "id": "#wf_gcmsearch.cwl/annot_merge/input"
                        }
                    ],
                    "out": [
                        "#wf_gcmsearch.cwl/annot_merge/annots"
                    ],
                    "id": "#wf_gcmsearch.cwl/annot_merge"
                },
                {
                    "run": "#cmsearch_wnode.cwl",
                    "in": [
                        {
                            "source": "#wf_gcmsearch.cwl/gpx_qsubmit/asncache",
                            "id": "#wf_gcmsearch.cwl/cmsearch_wnode/asn_cache"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/gpx_qsubmit/jobs",
                            "id": "#wf_gcmsearch.cwl/cmsearch_wnode/input_jobs"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/model_path",
                            "id": "#wf_gcmsearch.cwl/cmsearch_wnode/model_path"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/rfam_amendments",
                            "id": "#wf_gcmsearch.cwl/cmsearch_wnode/rfam_amendments"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/rfam_stockholm",
                            "id": "#wf_gcmsearch.cwl/cmsearch_wnode/rfam_stockholm"
                        }
                    ],
                    "out": [
                        "#wf_gcmsearch.cwl/cmsearch_wnode/asncache",
                        "#wf_gcmsearch.cwl/cmsearch_wnode/outdir"
                    ],
                    "id": "#wf_gcmsearch.cwl/cmsearch_wnode"
                },
                {
                    "run": "#gpx_qdump.cwl",
                    "in": [
                        {
                            "source": "#wf_gcmsearch.cwl/cmsearch_wnode/outdir",
                            "id": "#wf_gcmsearch.cwl/gpx_qdump/input_path"
                        }
                    ],
                    "out": [
                        "#wf_gcmsearch.cwl/gpx_qdump/annots"
                    ],
                    "id": "#wf_gcmsearch.cwl/gpx_qdump"
                },
                {
                    "run": "#gpx_qsubmit_gcmsearch.cwl",
                    "in": [
                        {
                            "source": "#wf_gcmsearch.cwl/asn_cache",
                            "id": "#wf_gcmsearch.cwl/gpx_qsubmit/asn_cache"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/seqids",
                            "id": "#wf_gcmsearch.cwl/gpx_qsubmit/seqids"
                        }
                    ],
                    "out": [
                        "#wf_gcmsearch.cwl/gpx_qsubmit/asncache",
                        "#wf_gcmsearch.cwl/gpx_qsubmit/jobs"
                    ],
                    "id": "#wf_gcmsearch.cwl/gpx_qsubmit"
                }
            ],
            "id": "#wf_gcmsearch.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
